@@ -2,6 +2,7 @@
 # vim: set et sts=2:
 # pylint: disable-msg=W0311,C0301,C0103,C0111,W0141,W0142
 
+import ConfigParser
 import json
 import logging
 import md5
@@ -19,9 +20,10 @@ from flask import jsonify
 
 from slapos.runner.gittools import cloneRepo
 
-from slapos.runner.process import Popen, isRunning, killRunningProcess
+from slapos.runner.process import Popen, isRunning, killRunningProcess, isPidFileProcessRunning
 from slapos.htpasswd import HtpasswdFile
 import slapos.slap
+from slapos.grid.utils import md5digest
 
 # Setup default flask (werkzeug) parser
 
@@ -112,6 +114,15 @@ def saveSession(config, account):
     return str(e)
 
 
+def getRcode(config):
+  parser = ConfigParser.ConfigParser()
+  try:
+    parser.read(config['knowledge0_cfg'])
+    return parser.get('public', 'recovery-code')
+  except (ConfigParser.NoSectionError, IOError) as e:
+    return None
+
+
 def createNewUser(config, name, passwd):
   htpasswdfile = os.path.join(config['etc_dir'], '.htpasswd')
   if os.path.exists(htpasswdfile):
@@ -131,8 +142,9 @@ def getCurrentSoftwareReleaseProfile(config):
         os.path.join(config['etc_dir'], ".project")).read()
     return realpath(
         config, os.path.join(software_folder, config['software_profile']))
+  # XXXX No Comments
   except:
-    return False
+    return ''
 
 
 def requestInstance(config, software_type=None):
@@ -173,6 +185,7 @@ def updateProxy(config):
   Configure Slapos Node computer and partitions.
   Send current Software Release to Slapproxy for compilation and deployment.
   """
+  startProxy(config)
   if not os.path.exists(config['instance_root']):
     os.mkdir(config['instance_root'])
   slap = slapos.slap.slap()
@@ -232,8 +245,8 @@ def startProxy(config):
     return
 
   log = os.path.join(config['log_dir'], 'slapproxy.log')
-  Popen([config['slapproxy'], '--log_file', log,
-         config['configuration_file_path']],
+  Popen([config['slapos'], 'proxy', 'start', '--logfile', log,
+         '--cfg', config['configuration_file_path']],
         name='slapproxy',
         stdout=None)
   time.sleep(4)
@@ -253,7 +266,7 @@ def removeProxyDb(config):
 
 def isSoftwareRunning(config=None):
   """
-    Return True if slapgrid-sr is still running and false if slapgrid if not
+    Return True if slapos is still running and false if slapos if not
   """
   # XXX-Marco what is 'config' for?
   return isRunning('slapgrid-sr')
@@ -268,17 +281,21 @@ def runSoftwareWithLock(config, lock=True):
     return False
 
   slapgrid_pid = os.path.join(config['run_dir'], 'slapgrid-sr.pid')
+  if isPidFileProcessRunning(slapgrid_pid):
+    return False
   if not os.path.exists(config['software_root']):
     os.mkdir(config['software_root'])
   stopProxy(config)
   startProxy(config)
-  logfile = open(config['software_log'], 'w')
+  # XXX Hackish and unreliable
+  if os.path.exists(config['software_log']):
+    os.remove(config['software_log'])
   if not updateProxy(config):
     return False
-  slapgrid = Popen([config['slapgrid_sr'], '-vc',
-                    '--pidfile', slapgrid_pid,
-                    config['configuration_file_path'], '--now', '--develop'],
-                   stdout=logfile, name='slapgrid-sr')
+  slapgrid = Popen([config['slapos'], 'node', 'software', '--all',
+                   '--cfg', config['slapos_cfg'], '--pidfile', slapgrid_pid,
+                   '--verbose', '--logfile', config['software_log']],
+                    name='slapgrid-sr')
   if lock:
     slapgrid.wait()
     #Saves the current compile software for re-use
@@ -291,9 +308,31 @@ def runSoftwareWithLock(config, lock=True):
 def config_SR_folder(config):
   """Create a symbolik link for each folder in software folder. That allows
     the user to customize software release folder"""
-  list = []
-  # XXX-Marco do not shadow 'list'
   config_name = 'slaprunner.config'
+  def link_to_folder(name, folder):
+    destination = os.path.join(config['software_link'], name)
+    source = os.path.join(config['software_root'], folder)
+    cfg = os.path.join(destination, config_name)
+        #create symlink
+    if os.path.lexists(destination):
+      os.remove(destination)
+    os.symlink(source, destination)
+        #write config file
+    if os.path.exists(source):
+      with open(cfg, 'w') as cf:
+        cf.write(current_project + '#' + folder)
+
+  # First create the link for current project
+  current_project = open(os.path.join(config['etc_dir'], ".project")).read()
+  profile = getCurrentSoftwareReleaseProfile(config)
+  if current_project[-1] == '/':
+     current_project = current_project[:-1]
+  name = current_project.split('/')[-1]
+  md5sum = md5digest(profile)
+  link_to_folder(name, md5sum)
+  # check other links
+  # XXX-Marco do not shadow 'list'
+  list = []
   for path in os.listdir(config['software_link']):
     cfg_path = os.path.join(config['software_link'], path, config_name)
     if os.path.exists(cfg_path):
@@ -307,26 +346,11 @@ def config_SR_folder(config):
     return
   if not folder_list:
     return
-  current_project = open(os.path.join(config['etc_dir'], ".project")).read()
-  if current_project[-1] == '/':
-     current_project = current_project[:-1]
-  name = current_project.split('/')[-1]
   for folder in folder_list:
     if folder in list:
       continue  # this folder is already registered
     else:
-      if not os.path.exists(os.path.join(config['software_link'], name)):
-        destination = os.path.join(config['software_link'], name)
-      else:
-        destination = os.path.join(config['software_link'], folder)
-      source = os.path.join(config['software_root'], folder)
-      cfg = os.path.join(destination, config_name)
-      #create symlink
-      os.symlink(source, destination)
-      #write config file
-      with open(cfg, 'w') as cf:
-        cf.write(current_project + '#' + folder)
-
+      link_to_folder(folder, folder)
 
 def loadSoftwareRList(config):
   """Return list (of dict) of Software Release from symbolik SR folder"""
@@ -344,7 +368,7 @@ def loadSoftwareRList(config):
 
 def isInstanceRunning(config=None):
   """
-    Return True if slapgrid-cp is still running and False otherwise
+    Return True if slapos is still running and False otherwise
   """
   # XXX-Marco what is 'config' for?
   return isRunning('slapgrid-cp')
@@ -360,13 +384,15 @@ def runInstanceWithLock(config, lock=True):
 
   slapgrid_pid = os.path.join(config['run_dir'], 'slapgrid-cp.pid')
   startProxy(config)
-  logfile = open(config['instance_log'], 'w')
+  # XXX Hackish and unreliable
+  if os.path.exists(config['instance_log']):
+    os.remove(config['instance_log'])
   if not (updateProxy(config) and requestInstance(config)):
     return False
-  slapgrid = Popen([config['slapgrid_cp'], '-vc',
-                    '--pidfile', slapgrid_pid,
-                    config['configuration_file_path'], '--now'],
-                    stdout=logfile, name='slapgrid-cp')
+  slapgrid = Popen([config['slapos'], 'node', 'instance', '--all',
+                   '--cfg', config['slapos_cfg'], '--pidfile', slapgrid_pid,
+                   '--verbose', '--logfile', config['instance_log']],
+                   name='slapgrid-cp')
   if lock:
     slapgrid.wait()
     return ( True if slapgrid.returncode == 0 else False )
@@ -728,7 +754,7 @@ def realpath(config, path, check_exist=True):
     'software_link': config['software_link']
   }
   if key not in allow_list:
-    return False
+    return ''
 
   del split_path[0]
   path = os.path.join(allow_list[key], *split_path)
@@ -736,7 +762,7 @@ def realpath(config, path, check_exist=True):
     if os.path.exists(path):
       return path
     else:
-      return False
+      return ''
   else:
     return path
 
@@ -770,29 +796,31 @@ def isSoftwareReleaseReady(config):
   """Return 1 if the Software Release has
   correctly been deployed, 0 if not,
   and 2 if it is currently deploying"""
+  auto_deploy = config['auto_deploy'] in TRUE_VALUES
+  auto_run = config['autorun'] in TRUE_VALUES
   project = os.path.join(config['etc_dir'], '.project')
-  if not os.path.exists(project):
+  if not ( os.path.exists(project) and (auto_run or auto_deploy) ):
     return "0"
   path = open(project, 'r').readline().strip()
   software_name = path
   if software_name[-1] == '/':
     software_name = software_name[:-1]
   software_name = software_name.split('/')[-1]
+  updateInstanceParameter(config)
   config_SR_folder(config)
   if os.path.exists(os.path.join(config['runner_workdir'],
       'softwareLink', software_name, '.completed')):
-    if config['autorun'] in TRUE_VALUES:
+    if auto_run:
       runSlapgridUntilSuccess(config, 'instance')
     return "1"
   else:
     if isSoftwareRunning(config):
       return "2"
-    elif config['auto_deploy'] in TRUE_VALUES:
-      configNewSR(config, path)
+    elif auto_deploy:
       runSoftwareWithLock(config)
       config_SR_folder(config)
       time.sleep(15)
-      if config['autorun'] in TRUE_VALUES:
+      if auto_run:
         runSlapgridUntilSuccess(config, 'instance')
       return "2"
     else:
@@ -817,7 +845,7 @@ def buildAndRun(config):
 
 
 def runSlapgridUntilSuccess(config, step):
-  """Run slapgrid-sr or slapgrid-cp several times,
+  """Run slapos several times,
   in the maximum of the constant MAX_RUN_~~~~"""
   params = getBuildAndRunParams(config)
   if step == "instance":
